@@ -11,44 +11,44 @@ from typing import Optional, Tuple, List, Union
 
 class TimeUtils:
     """时间工具类，提供各种时间相关的静态方法"""
-    
+
     # ==================== 当前时间获取 ====================
-    
+
     @staticmethod
     def get_current_date() -> str:
         """获取当前日期，格式为 YYYYMMDD"""
         return datetime.now().strftime('%Y%m%d')
-    
+
     @staticmethod
     def get_current_datetime() -> str:
         """获取当前日期时间，格式为 YYYYMMDDHHMMSS"""
         return datetime.now().strftime('%Y%m%d%H%M%S')
-    
+
     @staticmethod
     def current_datetime() -> str:
         """获取当前日期时间，格式为 YYYY-MM-DD HH:MM:SS"""
         return datetime.now().strftime('%Y-%m-%d %H:%M:%S')
-    
+
     @staticmethod
     def today_date() -> str:
         """获取今天的日期，格式为 YYYY-MM-DD"""
         return datetime.now().strftime('%Y-%m-%d')
-    
+
     @staticmethod
     def today_date_hour() -> str:
         """获取今天的日期和小时，格式为 YYYY-MM-DD_HH"""
         return datetime.now().strftime('%Y-%m-%d_%H')
-    
+
     @staticmethod
     def get_current_year() -> int:
         """获取当前年份"""
         return datetime.now().year
-    
+
     @staticmethod
     def get_current_month() -> int:
         """获取当前月份（1-12）"""
         return datetime.now().month
-    
+
     @staticmethod
     def get_current_year_range() -> Tuple[str, str]:
         """获取当前年份的开始和结束日期"""
@@ -56,9 +56,9 @@ class TimeUtils:
         start_date = datetime(current_year, 1, 1).strftime('%Y-%m-%d')
         end_date = datetime(current_year, 12, 31).strftime('%Y-%m-%d')
         return start_date, end_date
-    
+
     # ==================== 相对日期获取 ====================
-    
+
     @staticmethod
     def get_yesterday(dt: Optional[str] = None) -> str:
         """
@@ -76,28 +76,28 @@ class TimeUtils:
             dt = datetime.strptime(dt, "%Y%m%d")
         yesterday = dt - timedelta(days=1)
         return yesterday.strftime("%Y-%m-%d")
-    
+
     @staticmethod
     def before_yesterday() -> str:
         """获取前天的日期"""
         return (datetime.now().date() - timedelta(days=2)).strftime("%Y-%m-%d")
-    
+
     @staticmethod
     def tomorrow_date() -> str:
         """获取明天的日期"""
         return (datetime.now().date() + timedelta(days=1)).strftime("%Y-%m-%d")
-    
+
     @staticmethod
     def get_last_month() -> int:
         """获取上个月的月份"""
         today = datetime.today()
         last_month = today.month - 1 if today.month > 1 else 12
         return last_month
-    
+
     # ==================== 日期范围计算 ====================
-    
+
     @staticmethod
-    def get_past_7_days_range(start_from: Optional[str] = None) -> Tuple[str, str]:
+    def get_past_7_days_range(start_from: Optional[str] = None, format_str: str = '%Y-%m-%d') -> Tuple[str, str,]:
         """
         获取过去7天的日期范围（包括结束日，共7天）
         
@@ -122,8 +122,8 @@ class TimeUtils:
         end_date = base_date - timedelta(days=1)  # 默认昨天为结束
         start_date = end_date - timedelta(days=6)  # 往前推6天为开始
 
-        return start_date.strftime('%Y-%m-%d'), end_date.strftime('%Y-%m-%d')
-    
+        return start_date.strftime(format_str), end_date.strftime(format_str)
+
     @staticmethod
     def get_past_7_days_range_format(start_from: Optional[str] = None, format_str: str = '%Y-%m-%d') -> Tuple[str, str]:
         """
@@ -148,9 +148,9 @@ class TimeUtils:
         start_date = end_date - timedelta(days=6)  # 往前推6天为开始
 
         return start_date.strftime(format_str), end_date.strftime(format_str)
-    
+
     @staticmethod
-    def get_past_nth_day(n: int, start_from: Optional[str] = None) -> str:
+    def get_past_nth_day(n: int, start_from: Optional[str] = None, format_str: str = '%Y-%m-%d') -> str:
         """
         获取过去第n天的日期
         
@@ -174,8 +174,8 @@ class TimeUtils:
             base_date = datetime.today()
 
         past_date = base_date - timedelta(days=n)
-        return past_date.strftime('%Y-%m-%d')
-    
+        return past_date.strftime(format_str)
+
     @staticmethod
     def get_past_n_days_list(n: int, start_from: Optional[str] = None) -> List[str]:
         """
@@ -204,7 +204,7 @@ class TimeUtils:
             (base_date - timedelta(days=i)).strftime('%Y-%m-%d')
             for i in range(1, n + 1)
         ]
-    
+
     @staticmethod
     def get_past_7_days_list(start_from: Optional[str] = None) -> List[str]:
         """
@@ -228,7 +228,7 @@ class TimeUtils:
             (base_date - timedelta(days=i)).strftime('%Y-%m-%d')
             for i in range(1, 8)
         ]
-    
+
     @staticmethod
     def date_range(start_date: str, end_date: str) -> List[str]:
         """
@@ -257,7 +257,7 @@ class TimeUtils:
             current_date += timedelta(days=1)
 
         return date_list
-    
+
     @staticmethod
     def get_dates_from_first_of_month_to_yesterday() -> List[str]:
         """获取从本月第一天到昨天的日期列表"""
@@ -273,9 +273,9 @@ class TimeUtils:
             current_date += timedelta(days=1)
 
         return date_list
-    
+
     # ==================== 月份相关 ====================
-    
+
     @staticmethod
     def get_last_month_range() -> Tuple[str, str]:
         """获取上个月的第一天和最后一天"""
@@ -287,7 +287,7 @@ class TimeUtils:
         last_day = datetime(year, last_month, calendar.monthrange(year, last_month)[1])
 
         return first_day.strftime("%Y-%m-%d"), last_day.strftime("%Y-%m-%d")
-    
+
     @staticmethod
     def get_last_month_range_time_str() -> Tuple[str, str]:
         """获取上个月第一天和最后一天的时间字符串"""
@@ -302,7 +302,7 @@ class TimeUtils:
         end_time_str = last_day.strftime("%Y-%m-%d %H:%M:%S")
 
         return start_time_str, end_time_str
-    
+
     @staticmethod
     def get_last_month_range_time() -> Tuple[int, int]:
         """获取上个月第一天和最后一天的毫秒级时间戳"""
@@ -317,7 +317,7 @@ class TimeUtils:
         end_timestamp = int(last_day.timestamp() * 1000)
 
         return start_timestamp, end_timestamp
-    
+
     @staticmethod
     def is_in_month(time_str: str, month: int, fmt: str = "%Y-%m-%d") -> bool:
         """
@@ -336,16 +336,16 @@ class TimeUtils:
             return dt.month == month
         except ValueError:
             return False
-    
+
     # ==================== 星期相关 ====================
-    
+
     @staticmethod
     def get_week_num() -> int:
         """获取当前是第几周"""
         today = date.today()
         week_num = today.isocalendar()[1]  # 返回 (year, week_num, weekday)
         return week_num
-    
+
     @staticmethod
     def get_chinese_weekday(date_str: str) -> str:
         """
@@ -368,16 +368,16 @@ class TimeUtils:
             return weekday_cn[weekday_num]
         except ValueError as e:
             raise ValueError(f"日期格式错误，请输入'YYYY-MM-DD'格式的日期字符串。错误详情: {str(e)}")
-    
+
     @staticmethod
     def get_weekday_name(date_str: str) -> str:
         """获取中文星期名称（简短格式）"""
         weekdays = ['周一', '周二', '周三', '周四', '周五', '周六', '周日']
         date_obj = datetime.strptime(date_str, '%Y-%m-%d')
         return weekdays[date_obj.weekday()]
-    
+
     # ==================== 时间段相关 ====================
-    
+
     @staticmethod
     def get_period() -> str:
         """获取当前时间段（上午/下午/晚上）"""
@@ -388,16 +388,16 @@ class TimeUtils:
             return "下午"
         else:
             return "晚上"
-    
+
     @staticmethod
     def get_period2() -> str:
         """获取当前时间段（AM/PM）"""
         now = datetime.now()
         period = now.strftime("%p")  # 返回AM或者PM
         return period
-    
+
     # ==================== 时间戳转换 ====================
-    
+
     @staticmethod
     def convert_timestamp_to_str(timestamp_ms: Optional[int]) -> str:
         """
@@ -414,7 +414,7 @@ class TimeUtils:
         timestamp_s = int(timestamp_ms) / 1000
         dt = datetime.fromtimestamp(timestamp_s)
         return dt.strftime('%Y-%m-%d %H:%M:%S')
-    
+
     @staticmethod
     def convert_timestamp_to_date(timestamp_ms: Union[int, float]) -> str:
         """
@@ -429,7 +429,7 @@ class TimeUtils:
         timestamp_s = timestamp_ms / 1000
         dt = datetime.fromtimestamp(timestamp_s)
         return dt.strftime('%Y-%m-%d')
-    
+
     @staticmethod
     def get_start_timestamps(date_str: str) -> int:
         """
@@ -443,7 +443,7 @@ class TimeUtils:
         """
         start_of_day = datetime.strptime(date_str, "%Y-%m-%d")
         return int(start_of_day.timestamp() * 1000)
-    
+
     @staticmethod
     def get_end_timestamps(date_str: str) -> int:
         """
@@ -458,9 +458,9 @@ class TimeUtils:
         start_of_day = datetime.strptime(date_str, "%Y-%m-%d")
         end_of_day = start_of_day + timedelta(days=1) - timedelta(milliseconds=1)
         return int(end_of_day.timestamp() * 1000)
-    
+
     # ==================== 日期格式转换 ====================
-    
+
     @staticmethod
     def convert_datetime_to_date(datetime_str: str) -> str:
         """
@@ -482,7 +482,7 @@ class TimeUtils:
         except ValueError:
             print(f"输入的时间字符串格式错误，需要 'YYYY-MM-DD HH:MM:SS' 格式，但得到: {datetime_str}")
             return datetime_str
-    
+
     @staticmethod
     def date_trans(d_t: str) -> str:
         """
@@ -495,7 +495,7 @@ class TimeUtils:
             格式为 YYYYMMDD 的日期字符串
         """
         return datetime.strptime(d_t, "%Y-%m-%d").strftime("%Y%m%d")
-    
+
     @staticmethod
     def format_date_cross_platform(date_str: str) -> str:
         """
@@ -513,9 +513,9 @@ class TimeUtils:
             return date_obj.strftime("%Y/%#m/%#d")
         else:  # Linux, macOS等
             return date_obj.strftime("%Y/%-m/%-d")
-    
+
     # ==================== 日期比较和判断 ====================
-    
+
     @staticmethod
     def is_date_greater_or_equal(date_str: str) -> bool:
         """
@@ -535,7 +535,7 @@ class TimeUtils:
         except ValueError:
             print("日期格式不正确，请使用YYYY-MM-DD格式")
             return False
-    
+
     @staticmethod
     def is_yesterday(create_time_str: str, dt: Optional[str] = None) -> bool:
         """
@@ -559,7 +559,7 @@ class TimeUtils:
 
         yesterday = dt - timedelta(days=1)
         return create_time.date() == yesterday.date()
-    
+
     @staticmethod
     def is_yesterday_date(date_str: str) -> bool:
         """
@@ -579,9 +579,9 @@ class TimeUtils:
 
         yesterday = dt - timedelta(days=1)
         return create_time.date() == yesterday.date()
-    
+
     # ==================== 文件时间相关 ====================
-    
+
     @staticmethod
     def get_file_mtime(file_path: str, to_str: bool = True, tz_offset: int = 8) -> Union[str, datetime]:
         """
@@ -833,11 +833,11 @@ if __name__ == "__main__":
     print(f"当前周数: {get_week_num()}")
     print(f"当前时间段: {get_period()}")
     print(f"中文星期: {get_chinese_weekday(today_date())}")
-    
+
     # 测试日期范围
     start, end = get_past_7_days_range()
     print(f"过去7天范围: {start} 到 {end}")
-    
+
     # 测试时间戳转换
     current_ts = int(datetime.now().timestamp() * 1000)
     print(f"当前时间戳: {current_ts}")
