@@ -17,7 +17,7 @@ import hashlib
 import base64
 import requests
 from requests_toolbelt import MultipartEncoder
-
+from datetime import datetime
 
 # 通过企微群机器人发送消息
 class WxWorkBot:
@@ -51,6 +51,9 @@ class WxWorkBot:
             raise Exception("upload_media error", err)
 
     def send_file(self, file_path):
+        if not os.path.exists(file_path):
+            print('文件不存在: ', file_path)
+            return
         """
         发送文件到群里
         :param file_path:
@@ -59,7 +62,7 @@ class WxWorkBot:
         media_id = self.upload_media(file_path)
         data = {
             "msgtype": "file",
-            "file": {
+            "file"   : {
                 "media_id": media_id
             }
         }
@@ -75,7 +78,7 @@ class WxWorkBot:
         """
         data = {
             "msgtype": "text",
-            "text": {
+            "text"   : {
                 "content": content
             }
         }
@@ -93,13 +96,49 @@ class WxWorkBot:
         :return:
         """
         data = {
-            "msgtype": "markdown",
+            "msgtype" : "markdown",
             "markdown": {
                 "content": content
             }
         }
         self.send_msg(data)
 
+    def send_notify(self, title, sub_title_list, data_list):
+        """
+        发送Markdown消息
+        :param content:
+        :return:
+        """
+
+        current_date = datetime.now().strftime("%Y-%m-%d")
+        header = f"{current_date} {title}\n\n"
+
+        arr_color = ['warning', 'info', 'warning']
+        arr_sub_header = [f"<font color='{arr_color[index]}'>{title}</font>" for index, title in enumerate(sub_title_list)]
+        sub_header = "\t".join(arr_sub_header) + "\n\n"
+
+        # 获取每个元素的行索引和列索引
+        arr_content = [
+            [
+                f'{value}' if col_idx == 0 else f"<font color='{arr_color[col_idx - 1]}'>{value}</font>"
+                for col_idx, value in enumerate(row)
+            ]  # 每行的元素组成一个子列表
+            for row_idx, row in enumerate(data_list)  # 外层循环控制行
+        ]
+        # 将二维数组转换为字符串
+        content = "\n".join(
+            # 对每行的元素列表使用 join()，用 \t 连接
+            "\t".join(row) for row in arr_content
+        )
+
+        data = {
+            "msgtype" : "markdown",
+            "markdown": {
+                "content": header + sub_header + content
+            }
+        }
+        self.send_msg(data)
+
     def send_img(self, img_path):
         """
         发送图片消息
@@ -109,9 +148,9 @@ class WxWorkBot:
         """
         data = {
             "msgtype": "image",
-            "image": {
+            "image"  : {
                 "base64": self.img_to_base64(img_path),
-                "md5": self.img_to_md5(img_path)
+                "md5"   : self.img_to_md5(img_path)
             }
         }
         self.send_msg(data)
@@ -127,13 +166,13 @@ class WxWorkBot:
         """
         data = {
             "msgtype": "news",
-            "news": {
+            "news"   : {
                 "articles": [
                     {
-                        "title": title,
+                        "title"      : title,
                         "description": description,
-                        "url": url,
-                        "picurl": picurl
+                        "url"        : url,
+                        "picurl"     : picurl
                     }
                 ]
             }
@@ -172,7 +211,6 @@ class WxWorkBot:
             image_data = image_file.read()
             return base64.b64encode(image_data).decode('utf-8')
 
-
 # 通过企微应用发送消息
 class WxWorkAppBot:
     def __init__(self, corpid, corpsecret, agentid):
@@ -256,7 +294,7 @@ class WxWorkAppBot:
             url = "https://qyapi.weixin.qq.com/cgi-bin/media/get"
             params = {
                 "access_token": self.access_token,
-                "media_id": media_id
+                "media_id"    : media_id
             }
             response = requests.get(url=url, params=params)
             if response.status_code == 200:
@@ -271,4 +309,4 @@ class WxWorkAppBot:
                 print("HTTP Error:", response.status_code)
                 return None
         except Exception as err:
-            raise Exception("get media error", err)
\ No newline at end of file
+            raise Exception("get media error", err)
